pub struct ZstdCompressionEngine { /* private fields */ }Expand description
Compression engine for frozen memory tier using zstd Optimized for 5:1 compression ratio target with fast decompression
Implementations
Sourceimpl ZstdCompressionEngine
impl ZstdCompressionEngine
Sourcepub fn with_level(level: i32) -> Self
pub fn with_level(level: i32) -> Self
Create compression engine with custom level
Sourcepub fn compress_memory_data(
&self,
content: &str,
metadata: &Value,
) -> Result<CompressionResult>
pub fn compress_memory_data( &self, content: &str, metadata: &Value, ) -> Result<CompressionResult>
Compress memory content and metadata into a single compressed blob Returns compressed bytes and compression metrics
Sourcepub fn decompress_memory_data(
&self,
compressed_data: &[u8],
) -> Result<MemoryData>
pub fn decompress_memory_data( &self, compressed_data: &[u8], ) -> Result<MemoryData>
Decompress memory data back to original content and metadata Includes integrity validation
Sourcepub fn batch_compress(
&self,
memories: Vec<(&str, &Value)>,
) -> Result<Vec<CompressionResult>>
pub fn batch_compress( &self, memories: Vec<(&str, &Value)>, ) -> Result<Vec<CompressionResult>>
Batch compress multiple memories for efficient processing
Sourcepub fn estimate_compression_ratio(&self, content: &str) -> f64
pub fn estimate_compression_ratio(&self, content: &str) -> f64
Estimate compression ratio for planning purposes